<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *

 * @author    Gal Malinge <contact@akunet.fr>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0

 */


if (!defined('_PS_VERSION_')) {
    exit;
}

class Googlebusinessreviews extends Module
{
    protected $config_form = false;

    public function __construct()
    {
        $this->name = 'googlebusinessreviews';
        $this->tab = 'front_office_features';
        $this->version = '1.0.0';
        $this->author = 'Akunet';
        $this->need_instance = 0;

        /**
         * Set $this->bootstrap to true if your module is compliant with bootstrap (PrestaShop 1.6)
         */
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('Google Business Reviews');
        $this->description = $this->l('Display 5 basics google reviews of your business');

        $this->confirmUninstall = $this->l('Are your sure you want to uninstall this module ?');

        $this->ps_versions_compliancy = array('min' => '1.6', 'max' => '8.0');
    }

    /**
     * Don't forget to create update methods if needed:
     * http://doc.prestashop.com/display/PS16/Enabling+the+Auto-Update
     */
    public function install()
    {
	 Configuration::updateValue('GOOGLEBUSINESSREVIEWS_APIKEY', '');
	 Configuration::updateValue('GOOGLEBUSINESSREVIEWS_PLACEID', '');
     Configuration::updateValue('GOOGLEBUSINESSREVIEWS_SORT', '1');
	 Configuration::updateValue('GOOGLEBUSINESSREVIEWS_URLPLACE', '');

        return parent::install() &&
            $this->registerHook('header') &&
            $this->registerHook('displayBackOfficeHeader') &&
            $this->registerHook('displayHome');
    }

    public function uninstall()
    {

	 Configuration::deleteByName('GOOGLEBUSINESSREVIEWS_APIKEY', false);
	 Configuration::deleteByName('GOOGLEBUSINESSREVIEWS_PLACEID', false);
	 Configuration::deleteByName('GOOGLEBUSINESSREVIEWS_SORT', false);
	 Configuration::updateValue('GOOGLEBUSINESSREVIEWS_URLPLACE', false);

        return parent::uninstall();
    }

    /**
     * Load the configuration form
     */
    public function getContent()
    {
        /**
         * If values have been submitted in the form, process.
         */
        if (((bool)Tools::isSubmit('submitGooglebusinessreviewsModule')) == true) {
            $this->postProcess();
        }

        $this->context->smarty->assign('module_dir', $this->_path);

        $output = $this->context->smarty->fetch($this->local_path.'views/templates/admin/configure.tpl');

        return $output.$this->renderForm();
    }

    /**
     * Create the form that will be displayed in the configuration of your module.
     */
    protected function renderForm()
    {
        $helper = new HelperForm();

        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);

        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitGooglebusinessreviewsModule';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
            .'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');

        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFormValues(), /* Add values for your inputs */
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
        );

        return $helper->generateForm(array($this->getConfigForm()));
    }

    /**
     * Create the structure of your form.
     */
    protected function getConfigForm()
    {
        return array(
            'form' => array(
                'legend' => array(
                'title' => $this->l('Settings'),
                'icon' => 'icon-cogs',
                ),
                'input' => array(
                    array(
                        'col' => 2,
                        'type' => 'text',
                        'desc' => $this->l('Enter the Google API Key'),
                        'name' => 'GOOGLEBUSINESSREVIEWS_APIKEY',
                        'label' => $this->l('Google Api Key'),
                    ),
                    array(
                        'col' => 2,
                        'type' => 'text',
                        'name' => 'GOOGLEBUSINESSREVIEWS_PLACEID',
                        'desc' => $this->l('Enter the Google Business Place Id'),
                        'label' => $this->l('Google Business Place Id'),
                    ),
					array(
                        'col' => 2,
                        'type' => 'text',
                        'name' => 'GOOGLEBUSINESSREVIEWS_URLPLACE',
                        'desc' => $this->l('Enter the Google Business Place URL'),
                        'label' => $this->l('Google Business Place Url'),
                    ),
					array(
						'type' => 'select',
						'label' => $this->l('Ordre de classement des avis'),
						'name' => 'GOOGLEBUSINESSREVIEWS_SORT',
						'required' => true,
						'options' => array(
							'query' => $options = array(
                                    array(
                                      'id_option' => 1,
                                      'name' => 'Les plus pertinents',
                                    ),
                                    array(
                                      'id_option' => 2,
                                      'name' => 'Les plus récents',
                                    ),
							),
                           'id' => 'id_option',
                           'name' => 'name',
					    ),
                    ),
			      ),
                'submit' => array(
                    'title' => $this->l('Save'),
                ),
            ),
        );
    }

    /**
     * Set values for the inputs.
     */
    protected function getConfigFormValues()
    {
        return array(
            'GOOGLEBUSINESSREVIEWS_APIKEY' => Configuration::get('GOOGLEBUSINESSREVIEWS_APIKEY', ''),
            'GOOGLEBUSINESSREVIEWS_PLACEID' => Configuration::get('GOOGLEBUSINESSREVIEWS_PLACEID', ''),
            'GOOGLEBUSINESSREVIEWS_SORT' => Configuration::get('GOOGLEBUSINESSREVIEWS_SORT', ''),
			'GOOGLEBUSINESSREVIEWS_URLPLACE' => Configuration::get('GOOGLEBUSINESSREVIEWS_URLPLACE', ''),
        );
    }

    /**
     * Save form data.
     */
    protected function postProcess()
    {

	 //reset infos
	 $filename = _PS_MODULE_DIR_.'googlebusinessreviews/reviews.json';
	 unlink($filename);

        $form_values = $this->getConfigFormValues();

        foreach (array_keys($form_values) as $key) {
            Configuration::updateValue($key, Tools::getValue($key));
        }
    }

    /**
    * Add the CSS & JavaScript files you want to be loaded in the BO.
    */
    public function hookDisplayBackOfficeHeader()
    {

    }

    /**
     * Add the CSS & JavaScript files you want to be added on the FO.
     */
    public function hookHeader()
    {
        $this->context->controller->addCSS($this->_path.'/views/css/googlebusinessreviews.css');
    }

    public function hookDisplayHome()
    {

 	$shopname = Configuration::get('PS_SHOP_NAME');
	
	$filename = _PS_MODULE_DIR_.'googlebusinessreviews/reviews.json';
	$now = time() - 86400;

	if (file_exists($filename) && filemtime($filename) > $now) {

		$contenu = file_get_contents($filename);
		$contenu = json_decode($contenu,true);

        	$this->context->smarty->assign(array(
			'shopname' => $shopname,
			'url' => $contenu['result']['url'],
			'url_place' => Configuration::get('GOOGLEBUSINESSREVIEWS_URLPLACE'),
			'nbavis' => $contenu['result']['user_ratings_total'],
			'noteglobale' => $contenu['result']['rating'],
            		'reviews' => $contenu['result']['reviews'],
            		'note' => $contenu['result']['rating'],
            		)
		);

        	return $this->display(__FILE__, 'views/templates/hook/googlebusinessreviews.tpl');

	} else {
    
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_HTTPHEADER, array(
	    		"Cache-Control: no-cache",
		    	"content-type:application/json;charset=utf-8",
			    "Accept-Language: fr,fr-FR;q=0.8,en-US;q=0.5,en;q=0.3"
		));
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
		curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
		//Pour nouveau &reviews_sort=newest
		$order = Configuration::get('GOOGLEBUSINESSREVIEWS_SORT');
		if ($order == '1') {
			$filter = "&reviews_sort=most_relevant";
		} else {
			$filter = "&reviews_sort=newest";
		}

		//Requete
		curl_setopt($ch, CURLOPT_URL, "https://maps.googleapis.com/maps/api/place/details/json?placeid=".Configuration::get('GOOGLEBUSINESSREVIEWS_PLACEID')."&fields=name,url,rating,reviews,user_ratings_total&key=".Configuration::get('GOOGLEBUSINESSREVIEWS_APIKEY').$filter);

		$response = curl_exec($ch);
		//Debug print_r($response);
		
		$result = json_decode($response,true);

		if ($result['status'] == 'OK') {
			try {
				file_put_contents($filename, $response);
			} catch (Exception $e) {
    				echo 'Exception reue : ',  $e->getMessage(), "\n";
			}
		}

		curl_close($ch);

		$contenu = file_get_contents($filename);
		$contenu = json_decode($contenu,true);

        $this->context->smarty->assign(
			array(
				'shopname' => $shopname,
				'url' => $contenu['result']['url'],
				'url_place' => Configuration::get('GOOGLEBUSINESSREVIEWS_URLPLACE'),
				'nbavis' => $contenu['result']['user_ratings_total'],
				'noteglobale' => $contenu['result']['rating'],
            	'reviews' => $contenu['result']['reviews'],
            	'note' => $contenu['result']['rating'],
            )
		);

       	return $this->display(__FILE__, 'views/templates/hook/googlebusinessreviews.tpl');

	}

    }
}
